/* draw.h - Common definitions included by all source files */

/* Prevent multiple inclusion */
#ifndef _DRAW_H_INCLUDED
#define _DRAW_H_INCLUDED

/* Debug code included and run? */
/* #define DEBUG */

/* Standard system includes used by various source files */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <strings.h>
#include <time.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>

#ifdef __linux
/* getipt() on Linux needs this include */
#include <getopt.h>
#endif /* __linux */

#ifdef __hpux
/* pstat() on HP-UX needs these 2 includes */
#include <sys/param.h>
#include <sys/pstat.h>
#endif

#if defined(__APPLE__) && defined(__MACH__)
/* sysctl() on Mac OS X needs these headers */
#include <sys/types.h>
#include <sys/sysctl.h>
#endif /* __APPLE__ && __MACH__) */

/* If multi-threading, need to define the POSIX threads goodies */
#ifdef MULTITHREAD

/* POSIX threads definitions are in this include */
#include <pthread.h>
#ifdef HAVE_AFFINITY
/* Extra goodies for CPU/thread affinity */
#include <sched.h>
#endif

#define MAX_JOBS 10584 /* This is 54*(54-6+1)*4 - maximum number jobs on queue */

/* 2 CPU sockets * quad core * hyperthreading now means than 16 cores are
   available on recent servers. */
#define MAX_CPU_CORES 16

#define THREAD_SLEEP 10000 /* Sleep 0.01s in thread before checking for job */
#define HAMMER_TIME 0.05 /* Hammer CPU for this unit of time */

/* Job status codes for threads (stored in job_status[1..MAX_JOBS] array):
   0-MAX_CPU_CORES-1 = CPU core 0..MAX_CPU_CORES-1 has been allocated job
                       (note that "CPU core 0" is actually the parent process)
   MAX_CPU_CORES     = Idle, no job ready for allocation yet
   MAX_CPU_CORES+1   = Idle, job ready to be allocated
   MAX_CPU_CORES+2   = Idle, job completed. */
#define IDLE_NO_JOB_READY   MAX_CPU_CORES
#define IDLE_JOB_READY      (IDLE_NO_JOB_READY+1)
#define IDLE_JOB_COMPLETED  (IDLE_JOB_READY+1)

/* If we're using a fixed combination chunk size for a job
   (currently on 64-bit platforms only), then define it. */
#ifndef VARIABLE_COMBO_CHUNK
#define COMBO_CHUNK_SIZE 500000 /* Seems to be the optimal fixed chunk size */
#endif

#endif /* MULTITHREAD */

#define FILE_SLEEP 0.1 /* Sleep 0.1s between file checks */

/* Seems that the next 2 functions aren't always declared by
   the Linux system header files */
extern double drand48(void);
extern void srand48(long int);

/* Number of balls in machine. UK lottery = 49. Can be specified with the
   -b option. I've never seen a lottery with more than 54 balls. Let me know
   if you have ! */
#define DEF_UPPER 49   /* Default number of balls in machine (UK lottery) */
#define MAX_UPPER 54 /* You cannot specify more than this number of balls */

#define MIN_MATCH 3    /* Lowest number of matches in UK lottery for a prize */

/* Numbers required per ticket. UK lottery = 6. Can be specified with the
   -t option. */
#define DEF_DRAWN 6    /* Default numbers per ticket (UK lottery) */
#define MAX_DRAWN 7    /* Can't go higher than this */

/* Calculated by printf("%ld\n",MAXINT); */
#ifndef MAXINT
#define MAXINT 2147483647
#endif

#define NUM_PAIRS 15 /* 2 from 6 */

#define ZENITY_BINARY "/usr/bin/zenity" /* Zenity binary (needs X11 and GTK+) */

/* You can adjust the 3-match prize using the -T option either for "fun" to
   see the effect on other prizes or if does actually change in real-life */
#define THREE_MATCH_PRIZE_DEFAULT 10 /* 10 pounds is the current prize */
#define THREE_MATCH_PRIZE_MIN      2 /* 1 pound would be dumb (= stake!) */
#define THREE_MATCH_PRIZE_MAX     20 /* 20 pounds enough to trigger overflow */

/* Latest Cygwin library on Windows needs to use 2-byte Unicode to display
   a pound symbol in the console. Thanks a bunch! */
#ifdef UNICODE
#define POUND_SYMBOL "\xc2\xa3"
#define POUND_LENGTH 2
#else
#define POUND_SYMBOL "\xa3"
#define POUND_LENGTH 1
#endif

#endif /* _DRAW_H_INCLUDED */
