/* gui.c - (C) Richard K. Lloyd 2010 <webmaster@lottery.merseyworld.com>

   Use zenity to provide input and output dialogue boxes, but only if:
   - $DISPLAY is set
   - /usr/bin/zenity is present
   - -g is supplied on the command-line
*/

/* Global definitions */
#include "draw.h"

static int use_gui=0; /* Don't use GUI by default */

void request_gui(void)
/* Routine called if -g supplied */
{
   struct stat finfo;
   use_gui=(getenv("DISPLAY")!=(char *)NULL && !stat(ZENITY_BINARY,&finfo)
            && finfo.st_size);
}

char *ask_for_string(char *prompt)
{
   static char retval[BUFSIZ];

   retval[0]='\0';
   if (use_gui)
   {
      char zencomm[BUFSIZ];
      FILE *phand;

      (void)sprintf(zencomm,"%s --entry --title=\"%s\" --text=\"%s\" </dev/null 2>/dev/null",ZENITY_BINARY,prompt,prompt);
      if ((phand=popen(zencomm,"r"))!=(FILE *)NULL)
      {
         if (fgets(retval,BUFSIZ,phand)!=(char *)NULL)
         {
            int sl=strlen(retval)-1;
            if (sl>=0 && (retval[sl]=='\n' || retval[sl]=='\r'))
               retval[sl]='\0';
         }
         (void)pclose(phand);
      }
   }
   else
   {
      (void)fprintf(stderr,"\n%s : ",prompt);
      if (fgets(retval,BUFSIZ,stdin)!=(char *)NULL)
      {
         int sl=strlen(retval)-1;
         if (sl>=0 && (retval[sl]=='\n' || retval[sl]=='\r'))
            retval[sl]='\0';
      }
   }

   return(retval);
}

long ask_for_value(char *prompt)
{
   long retval=0;
   char zenret[BUFSIZ];

   if (use_gui)
   {
      char zencomm[BUFSIZ];
      FILE *phand;

      (void)sprintf(zencomm,"%s --entry --title=\"%s\" --text=\"%s\" </dev/null 2>/dev/null",ZENITY_BINARY,prompt,prompt);
      if ((phand=popen(zencomm,"r"))!=(FILE *)NULL)
      {
         if (fgets(zenret,BUFSIZ,phand)!=(char *)NULL) retval=atol(zenret);
         (void)pclose(phand);
      }
   }
   else
   {
      (void)fprintf(stderr,"\n%s : ",prompt);
      if (fgets(zenret,BUFSIZ,stdin)!=(char *)NULL) retval=atol(zenret);
   }

   return(retval);
}
